@@ -4,9 +4,10 @@ from . import (
     directory,
     event,
     functional,
-    stream,
+    pipe,
     subprocess,
-    tasks)
+    tasks,
+    utils)
 
 
 __all__ = (
@@ -14,6 +15,7 @@ __all__ = (
     "directory",
     "event",
     "functional",
-    "stream",
+    "pipe",
     "subprocess",
-    "tasks")
+    "tasks",
+    "utils")
