@@ -1,13 +1,14 @@
 """aio.core.subprocess."""
 
 from .async_subprocess import AsyncSubprocess, run, parallel
-from .abstract import AAsyncShell
-from .shell import AsyncShell
+from .handler import ASubprocessHandler, ISubprocessHandler
+from . import exceptions
 
 
 __all__ = (
+    "exceptions",
     "run",
     "parallel",
-    "AAsyncShell",
+    "ASubprocessHandler",
     "AsyncSubprocess",
-    "AsyncShell")
+    "ISubprocessHandler")
